@@ -975,7 +975,7 @@ class Scheduler(PollScheduler):
                         continue
 
                     if fetched:
-                        bintree.inject(x.cpv, filename=fetched)
+                        bintree.inject(x.cpv, current_pkg_path=fetched)
 
                     infloc = os.path.join(build_dir_path, "build-info")
                     ensure_dirs(infloc)
